==> jersey-server-2.9-sources.jar: org/glassfish/jersey/server/internal/monitoring/ResponseStatisticsImpl.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2013-2014 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * http://glassfish.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package org.glassfish.jersey.server.internal.monitoring;

import java.util.Map;

import org.glassfish.jersey.server.monitoring.ResponseStatistics;

import jersey.repackaged.com.google.common.collect.Maps;

/**
 * @author Miroslav Fuksa (miroslav.fuksa at oracle.com)
 *
 */
class ResponseStatisticsImpl implements ResponseStatistics {
    private final Map<Integer, Long> responseCodes;
    private final Integer lastResponseCode;


    static class Builder {
        private Map<Integer, Long> responseCodes = Maps.newHashMap();
        private Integer lastResponseCode = null;

        void addResponseCode(int responseCode) {
            lastResponseCode = responseCode;
            Long currentValue = responseCodes.get(responseCode);
            if (currentValue == null) {
                currentValue = 0l;
            }
            responseCodes.put(responseCode, currentValue + 1);
        }

        ResponseStatisticsImpl build() {
            return new ResponseStatisticsImpl(lastResponseCode, responseCodes);
        }

    }

    private ResponseStatisticsImpl(Integer lastResponseCode, Map<Integer, Long> responseCodes) {
        this.lastResponseCode = lastResponseCode;
        this.responseCodes = responseCodes;
    }

    @Override
    public Integer getLastResponseCode() {
        return lastResponseCode;
    }

    @Override
    public Map<Integer, Long> getResponseCodes() {
        return responseCodes;
    }

    @Override
    public ResponseStatistics snapshot() {
        // snapshot functionality not yet implemented
        return this;
    }
}

==> jersey-server-2.15-sources.jar: org/glassfish/jersey/server/internal/monitoring/ResponseStatisticsImpl.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2013-2014 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * http://glassfish.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package org.glassfish.jersey.server.internal.monitoring;

import java.util.Map;

import org.glassfish.jersey.server.monitoring.ResponseStatistics;

import jersey.repackaged.com.google.common.collect.Maps;

/**
 * @author Miroslav Fuksa (miroslav.fuksa at oracle.com)
 */
final class ResponseStatisticsImpl implements ResponseStatistics {

    private final Map<Integer, Long> responseCodes;
    private final Integer lastResponseCode;

    static class Builder {

        private final Map<Integer, Long> responseCodes = Maps.newHashMap();
        private Integer lastResponseCode = null;

        private ResponseStatisticsImpl cached = null;

        void addResponseCode(final int responseCode) {
            cached = null;

            lastResponseCode = responseCode;
            Long currentValue = responseCodes.get(responseCode);
            if (currentValue == null) {
                currentValue = 0l;
            }
            responseCodes.put(responseCode, currentValue + 1);
        }

        ResponseStatisticsImpl build() {
            if (cached == null) {
                cached = new ResponseStatisticsImpl(lastResponseCode, responseCodes);
            }
            return cached;
        }

    }

    private ResponseStatisticsImpl(final Integer lastResponseCode, final Map<Integer, Long> responseCodes) {
        this.lastResponseCode = lastResponseCode;
        this.responseCodes = responseCodes;
    }

    @Override
    public Integer getLastResponseCode() {
        return lastResponseCode;
    }

    @Override
    public Map<Integer, Long> getResponseCodes() {
        return responseCodes;
    }

    @Override
    public ResponseStatistics snapshot() {
        // snapshot functionality not yet implemented
        return this;
    }
}
